#!/bin/bash
#set -x

# InstallFlashImage.sh
# 
# Start up script that will query user for a bootserver and
# mount point, mount the server, look for FlashImages, (IDFs)
# and present a list of the IDFs and prompt the user to select
# which image they want to install to their flash. Once an 
# image is selected, it will call a script to partition, format
# and mount the flash to /mnt/hd1, and then call "lcma", the
# update binary to update the mounted flash with the IDF the
# user selected.
#
#


function chooseLocalRemote
{
	echo -n "Use current boot server?([y]/n): "; read -r input
        case $input in
                ""|[yY]|[yY][eE][sS]) 
                   USINGEXISTINGFS=y
                   ;;
		[nN]|[nN][oO])
                   USINGEXISTINGFS=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			chooseLocalRemote;;
	esac
}

function getBootServer 
{
	echo -n "What is the IP of your recovery server?: "; read -r BOOTSERVER
	check_valid $BOOTSERVER "getBootServer"
}

function getMountPoint
{
	echo -n "What is the mount point of your recovery server?: "; read -r MOUNTPOINT
	if [ ! $MOUNTPOINT ]
		then 
			echo -e "\nNo value set.  Using defaults.\n"
			MOUNTPOINT=/nstation/linux
	fi
}

function listMountPoints
{
	echo -e "\nAvailable mounts on: $BOOTSERVER\n\n"
	LINECOUNT=`showmount -e $BOOTSERVER | wc -l`
	TEMP=`showmount -e $BOOTSERVER | grep -vE "Export list" | tr -s "*" " " | cut -f1 -d" " | tr -s "\n" "\t"`
	TEMPC=1	
	while [ $TEMPC -lt $LINECOUNT ]
	do
		MountArray[$TEMPC]=`echo $TEMP | cut -f$TEMPC -d" " | cut -f1 -d" "`
		echo -e "\t $TEMPC. ${MountArray[$TEMPC]}"
		TEMPC=$((TEMPC+1))
	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a mount point: "; read -r SELECT
	checkForRange $SELECT $((LINECOUNT-1)) "listMountPoints"
	MOUNTPOINT=${MountArray[$SELECT]}
}

function unmountBootServer
{
	echo -n "Unmounting Server..."
	umount $DEFAULT_MOUNTPOINT
	echo -e " Done."
}

function mountBootServer
{
	if [ $MOUNTPOINT ] && [ $BOOTSERVER ]
		then 
			echo -e "\n\n"
			echo  "Mounting $BOOTSERVER:$MOUNTPOINT  Please wait..."
			mkdir -p $DEFAULT_MOUNTPOINT
			# Unmount any left over mounts, before mounting default_mountpoint
			unmountBootServer

			if mount $BOOTSERVER:$MOUNTPOINT $DEFAULT_MOUNTPOINT
				then echo -e " Mount successful."
				else
					echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT:"
					unmountBootServer
			fi

		else
			echo -e "\n\n"
			echo -e "Recovery server and mount point not both specified.\n"
			echo -e "Assuming $IMAGENAME is in file system.\n"
			USINGEXISTINGFS=y

	fi
	if [ -f $IMAGENAME ]
		then
			echo -e "Image found.\n"
		else
			echo -e "Image not present or not accessible.\n"
	fi
	echo -e "\n"
}

function listFlashImages
{
        # add check for existance of some idf files  ???


    	if [ "$USINGEXISTINGFS" != "y" ] ; then
		IDF_DIR=$DEFAULT_MOUNTPOINT$DEFAULT_IMAGE_DIR
		echo -e "\nAvailable Flash Images on: $BOOTSERVER:$MOUNTPOINT\n\n"
	else
		IDF_DIR=$DEFAULT_IMAGE_DIR
		echo -e "\nAvailable Flash Images in: $IDF_DIR\n\n"
	fi

	count=1

	flash_size=`/IBM/bin/e2fs_flash_info.sh | grep total_useable_bytes | cut -d= -f2`

	for i in $IDF_DIR/*.idf; do

        	idf_size=`awk '{ if( match( $1, /^[Hh][Ee][Aa][Dd]/ )) { for( i=2; i<=NF; i++ ) { if ( match( $i, /^[Cc][Oo][Mm][Pp][Rr][Ee][Ss][Ss][Ee][Dd][Ss][Ii][Zz][Ee]=/ )) { print substr( $i, 16 ) ; exit }} ; exit }}' $i`

        	if [ -z "$flash_size" ]; then
                        IDFArray[$count]=$i
                        echo -e "\t $count. `basename ${IDFArray[$count]}`"
                        count=$((count+1))
		elif [ `expr $idf_size \< $flash_size` = "1" ]; then
                        IDFArray[$count]=$i
                        echo -e "\t $count. `basename ${IDFArray[$count]}`"
                        count=$((count+1))
		else
                        echo -e ""
                        echo -e "\t`basename $i` is too large for this flash card."
                        echo -e ""
		fi

	done
	echo -e "\t 0. Quit"
	echo -e "\n"
	echo -n "Choose a Flash Image: "; read -r CHOICE
	checkForRange $CHOICE  $((count-1)) "listFlashImages"
	IMAGENAME=${IDFArray[$CHOICE]}
	export IMAGENAME
	
}

function checkForFlashReboot
{
        echo -e "\n"
	echo -n "On flash completion, do you want to reboot to Flash ([y]/n) ?: "; read -r input
        case $input in
		""|[yY]|[yY][eE][sS]) 
                   FLASH_REBOOT=y
                   ;;
		[nN]|[nN][oO])
                   FLASH_REBOOT=n
                   ;;
		*)
			echo -e "\nInvalid Response\n"
			checkForFlashReboot;;
	esac


}

function checkForDeltaUpdates
{
        DELTA_UPDATE=n
        echo -e "\n"
	echo -n "Is this a delta update of the flash [n] (y/n) ?: "; read -r input
        case $input in
		[yY]|[yY][eE][sS]) 
                   DELTA_UPDATE=y
                   PARTITION_FLASH=n
                   ;;
		*)
                   ;;
 	esac


}

function checkForPartitionFlash
{
        if [ "$DELTA_UPDATE" = n ]; then 
                echo -e "\n"
                echo "Note: If the flash is not partitioned, it will have errors in subsequent steps"
                echo -n "Do you want to create the flash partition [ y ] : (y/n) ? "; read -r input

                case $input in
                ""|[yY]|[yY][eE][sS]) 
                   PARTITION_FLASH=y
                   ;;
                [nN]|[nN][oO])
                   PARTITION_FLASH=n
                   ;;
		*)
        	   echo -e "\nInvalid Response\n"
		   checkForPartitionFlash;;
                esac
        fi


}

function checkForRange # number upperlimit callingFunction
{
	BADCHOICE=0
	if [ $1 -eq 0 ]
		then
			umount $DEFAULT_MOUNTPOINT
			sync;sync;sync
			exit
	fi

	if [ $1 -lt 1 ]
		then 
			BADCHOICE=1
	fi

	if [ $1 -gt $2 ]
		then
			BADCHOICE=1
	fi

	if [ $BADCHOICE -eq 1 ]
		then
			BADCHOICE=0
			echo -e "\nInvalid value.\n"
			$3
	fi
}

function callFlashInit
{
        if [ x$PARTITION_FLASH = x"y" ]; then
            echo -n "Partitioning Flash... Please Wait. "
           . /IBM/FlashRecovery/cf_flashinit.sh
        else
           echo -n "Mounting Flash... Please Wait. "
          . /IBM/FlashRecovery/cf_umount.sh
          . /IBM/FlashRecovery/cf_mount.sh
        fi
        echo " Done."
}

function updateFlash 
{
	echo -e "\n"
	if [ "$USINGEXISTINGFS" != "y" ] ; then
		# Ftp support
    FTPNEEDED=`echo $1 | cut -c1-6`
    if [ "$FTPNEEDED" = "ftp://" ]; then		
			file=$1
			M_OPTION=
		else
 			file=`echo $1 | cut -c12- `
			M_OPTION="-m $DEFAULT_MOUNTPOINT"
		fi	
	else
		file=$1
		M_OPTION=
	fi
	
    if [ "$DELTA_UPDATE" = "y" ]; then
        UPDATE_MESSAGE="Updating Compact Flash Image with $1 "
	F_OPTION=
	T_OPTION="-t 200"
    else
        UPDATE_MESSAGE="Creating New Compact Flash Image with $1 "
	F_OPTION="-f"
	T_OPTION="-t 203"
    fi

   if [ "$FLASH_RECOVERY_MODE" != "y" ]; then
		U_OPTION="-u"
	 else
		U_OPTION=
	 fi	

  if [ "$PROXYURL" ]; then
		P_OPTION=`echo "-p" $PROXYURL`
  else
	  P_OPTION=
  fi	

#  if [ "$LOG_SERVER_URL" ]; then
#			L_OPTION=`echo "-l" $LOG_SERVER_URL`
#	 else
#		  L_OPTION=
#	 fi	

    echo $UPDATE_MESSAGE
    echo "... Please wait. "
    if [ ! -e /var/log/lcma ]; then
       mkdir -p /var/log/lcma
    fi

    # echo -e "/IBM/bin/lcma $T_OPTION $F_OPTION -s $file $M_OPTION -r /mnt/hd1 $C_OPTION"
    /IBM/bin/lcmaStart $U_OPTION $P_OPTION $T_OPTION $F_OPTION -s $file $M_OPTION -r /mnt/hd1 -c $file
}

function check_valid # number callingFunction 
{
	BADVAL=0
        TEMP=`echo $1 | tr -d "[a-z][A-Z][\-\"]"`
        if [ ${#TEMP} -ne ${#1} ]
                then BADVAL=1
        fi

        TEMP=`echo $1 | cut -f1 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f2 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f3 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi
        TEMP=`echo $1 | cut -f4 -d"."`
        if [ $TEMP -gt 255 ]
                then BADVAL=1
        fi

	if [ $BADVAL -eq 1 ]
		then
			BADVAL=0
			echo -e "\nInvalid value\n";
			$2
	fi
} 

function check_for_automate
{

   if [ "$FLASH_RECOVERY_MODE" = "n" -a "$BOOTSOURCE" = "server" ]; then
	   . /IBM/FlashRecovery/cf_umount.sh
      . /IBM/FlashRecovery/cf_mount.sh
   fi

	if [ -f $AUTOUPDATE_PATH ]; then
		. $AUTOUPDATE_PATH
	else
		PROMPTFORSERVER=y
	fi

   if [ "$FLASH_RECOVERY_MODE" != "y" -a "$BOOTSOURCE" = "server" ]; then
      . /IBM/FlashRecovery/cf_umount.sh
   fi

	if [ "$PROMPTFORSERVER" != "y" ]; then
  		# Ftp support 
                FTPNEEDED=`echo $IMAGENAME | cut -c1-6`
                if [ "$FTPNEEDED" != "ftp://" ]; then
                        mountBootServer				
		fi				
	else
		if [ "$FLASH_RECOVERY_MODE" = "n" -a "$BOOTSOURCE" = "flash" ]; then
		   USINGEXISTINGSFS=n	
		else
                        if [ "$FLASH_RECOVERY_MODE" = "n" ]; then
                                chooseLocalRemote
                        else
                                USINGEXISTINGFS=y
                                DELTA_UPDATE=n
                                PARTITION_FLASH=y
                                FLASH_REBOOT=y
                                CONFIRM_REBOOT=n
                        fi
		fi
                if [ "$USINGEXISTINGFS" != "y" ]; then
                        if [ ! $BOOTSERVER ]; then 
                                getBootServer
                        fi
                        if [ ! $MOUNTPOINT ]; then
                                listMountPoints
                        fi
                        mountBootServer
                fi
                listFlashImages
		if [ "$FLASH_RECOVERY_MODE" = "n" -a "$BOOTSOURCE" != "flash" ]; then
		   checkForDeltaUpdates
		   checkForPartitionFlash
			checkForFlashReboot
		fi

	fi			
}

function flashReboot
{
   echo "Set for Flash Reboot"

   # Uncomment next 2 lines for debug
   # echo "For debug - type exit to continue "
   # /bin/sh

   #  Check for error in building flash - if error, do not reboot ??? 

   # write to nvram - Boot file is /kernel.2#00 and localboot=Flash
   # tcPrimaryBootServerDirectory (id=22) is set to 4 - flashPrimaryBootDirDefault
   # echo -e "/IBM/bin/writeNvram   22   4"
   /IBM/bin/writeNvram   22   4

   # tcDHCPPriority (id=31) 1 if Boot protocol is set to use DHCP  
   /IBM/bin/readNvram   31   
   DHCP_IS_SET=`cat /tmp/snmp/31`
   if [ $BOOTSOURCE != "flash" ]; then
      if [ "$DHCP_IS_SET" = "0" ]; then
        # tcFlashBootProtocol  nvram id=79 mib is 83
        # Server NVRAM booted set to boot from Flash using NVRAM settings
        /IBM/bin/writeNvram   79   0
      else
        # tcFlashBootProtocol  nvram id=79 mib is 83
        # Server DHCP booted set to boot from Flash using DHCP
        /IBM/bin/writeNvram   79   1
        # tcDHCPPriority (id=31) 1 if Boot protocol is set to use DHCP 
        # Clear Server DHCP booted bit
        /IBM/bin/writeNvram   31   0
        # tcNVRAMPriority (id=32) 1 if Boot protocol is set to use NVRAM static ip values 
        # Set Server NVRAM booted bit
        /IBM/bin/writeNvram   32   1
      fi
   fi
   # tcLocalPriority (id=33) is set to 1 - flash boot
   # echo -e "/IBM/bin/writeNvram   33   1"
   /IBM/bin/writeNvram   33   1
   # Clear tcNVRAMOverrideDHCPServerSettings bit NVRAM id=56 
   /IBM/bin/writeNvram   56   0
  

   cd /IBM/FlashRecovery
   umount /mnt/hd1
   umount /mnt/hd2 
   sync;sync;sync
   # Reboot - forced w/o user confirmation
   if [ "$CONFIRM_REBOOT" = "y" ]; then
      echo -e "\n"
      echo -n "NVRAM changed to do flash reboot - Continue with reboot [y] : (y/n) ? "; read -r input
      if [ $input ]; then
        if [ x$input == x"y" ]; then
                # echo -e "/IBM/bin/reboot_IBM_NS   5\n"
                /IBM/bin/reboot_IBM_NS   5
        fi
      else
        /IBM/bin/reboot_IBM_NS   5
      fi
   else
   	# echo -e "/IBM/bin/reboot_IBM_NS   5\n"   
        /IBM/bin/reboot_IBM_NS   5
   fi

}


#------------------------
# Start Main section 
#------------------------

# parse the kernel command line
`awk -f/bin/cmdline_export_awk /proc/cmdline`

if [ $# = 1 ] && [ "$1" = "--update" ] || [ "$root" != "nfs" ]; then
	FLASH_RECOVERY_MODE=n
	AUTOUPDATE_PATH=/mnt/hd1/IBM/autoupdate
	if [ "$root" != "nfs" ]; then
		BOOTSOURCE=flash
		if [ "$TERM" = "xterm" ]; then
			# we are running this script booted to flash
			# remove the autoupdate file so we can regenerate it
			rm -f /IBM/autoupdate
		fi
	else
		BOOTSOURCE=server
	fi
else
	if [ $# = 0 ]; then
		FLASH_RECOVERY_MODE=y
		AUTOUPDATE_PATH=/IBM/FlashRecovery/autoupdate
		BOOTSOURCE=server
	else
		echo -e "usage: cf_InstallFlashImage.sh [--update]\n"
		echo -e "The default mode of operation reads the autoupdate from the server.\n"
		echo -e "       --update reads the autoupdate from the flash card.\n"
		exit 1
	fi
fi

#set-up defaults
FLASH_REBOOT=n
CONFIRM_REBOOT=y

#definitions for standard mount directory and images directory
DEFAULT_MOUNTPOINT=/mnt/update
DEFAULT_IMAGE_DIR=/IBM/update/idf
LCMA_LOG=/var/log/lcma/recovery.log
LCMA_ERR=/var/log/lcma/recovery.err

# -- Start

# /usr/bin/clear
echo -e "\nWelcome to IBM NetVista Flash Recovery Tool v1.0\n\n"

# If flash booted then symlink /mnt/hd1 and /mnt/hd2 to the root dirs of the flash partitions
if [ "$BOOTSOURCE" == "flash" ]; then 
   # try to remove if symlinks
   rm -f /mnt/hd1
   rm -f /mnt/hd2
   if [ -d /mnt/hd1 ]; then
      echo "Error: /mnt/hd1 directory exists on flash card"
      exit
   fi
   if [ -d /mnt/hd2 ]; then
      echo "Error: /mnt/hd2 directory exists on flash card"
      exit
   fi
   if [ ! -d /mnt ]; then
      mkdir /mnt
   fi
   # Make the symlinks
   ln -sf / /mnt/hd1
   ln -sf /root /mnt/hd2
fi


# Get inputs, if "autoupdate" file is not present
check_for_automate

# Partition/initialize Flash, if specified and mount /dev/hda1 and /dev/hda2
if [ "$BOOTSOURCE" != "flash" ]; then
   callFlashInit
fi

if [ "$TERM" = "xterm" -a $BOOTSOURCE = "flash" ]; then
	# calling this script from an xterm booted from flash
	# we will only write the /IBM/autoupdate file and then reboot
	# so the software update can happen in "minimal" mode
	echo "BOOTSERVER=$BOOTSERVER" > /IBM/autoupdate
	echo "MOUNTPOINT=$MOUNTPOINT" >> /IBM/autoupdate
	echo "IMAGENAME=$IMAGENAME" >> /IBM/autoupdate
	echo "DELTA_UPDATE=y" >> /IBM/autoupdate
	echo "PARTITION_FLASH=n" >> /IBM/autoupdate
	echo "FLASH_REBOOT=y" >> /IBM/autoupdate
 	echo "CONFIRM_REBOOT=n" >> /IBM/autoupdate
	/IBM/bin/writeNvram 43 1
     sync
	sync
	echo "Press <Enter> to reboot and update the flash card: "
     read -r input
	echo 0 > /tmp/reboot

else
	# Update flash - calls lcma  
   updateFlash $IMAGENAME
fi

if [ $BOOTSOURCE != "flash" ]; then
   # remove 'root' symlink
   rm -f /mnt/hd1/root
   # create root mountpoint now
   mkdir /mnt/hd1/root
fi

# turn off compress on necessary files
chattr -c /mnt/hd1/kernel.*
chattr -c /mnt/hd1/sbin/init

if [ $BOOTSOURCE != "flash" ]; then
   # Configure network settings
   mkdir /mnt/hd2/IBM

   # create lcma log directory
   mkdir /mnt/hd2/lcma

   # create lpd spool directory
   mkdir /mnt/hd2/lpd
   chown daemon:daemon /mnt/hd2/lpd

   # set permissions on KIOSK directory
   chown -R 500 /mnt/hd2/KIOSK
fi

if [ ! -f /mnt/hd2/KIOSK.tar.gz ]; then
   tar -czf /mnt/hd2/KIOSK.tar.gz -C /mnt/hd2/ KIOSK
fi

#Unmount server on default_mountpoint
unmountBootServer

# Reboot from flash if so requested
if [ x$FLASH_REBOOT = x"y" ]; then
    flashReboot
fi
