#!/bin/bash
#set -x

function pre_createRamDisk
{
       echo "starting pre-ramdisk setup" >> /tmp/ramdisk_log
       # lets set up the ramdisk
       # zero out a 32/48M ramdisk...
       dd if=/dev/zero of=/dev/ram4 bs=1k count=49152 

       # create an ext2 filesystem on the ramdisk
       /sbin/mke2fs -vm0 /dev/ram4 49152  
       if [ ! -d /mnt/ramdisk ]; then
          mkdir /mnt/ramdisk
       fi
       mount /dev/ram4 /mnt/ramdisk
       #compression 
       chattr +c /mnt/ramdisk

       echo "Generating ramdisk..."

       # generate dev entries...
       sh /IBM/FlashRecovery/cf_devinit.sh /mnt/ramdisk

       echo "done with pre-ramdisk setup" >> /tmp/ramdisk_log
}


function write_linuxrc
{
echo "echo-generating linuxrc " >> /tmp/ramdisk_log
echo "#!/bin/sh                                                            " > /mnt/ramdisk/linuxrc.tst
echo "PATH=\"/bin:/sbin:/usr/bin:/usr/sbin:/usr/X11R6/bin:/etc:/etc/rc.d\" " >> /mnt/ramdisk/linuxrc.tst
echo "TERM=linux                                                           " >> /mnt/ramdisk/linuxrc.tst
echo "ignoreeof=10                                                         " >> /mnt/ramdisk/linuxrc.tst
echo "export PATH TERM PS1 PS2                                             " >> /mnt/ramdisk/linuxrc.tst
echo "umask 022                                                            " >> /mnt/ramdisk/linuxrc.tst
echo "mount -t proc proc /proc                                             " >> /mnt/ramdisk/linuxrc.tst
echo "cd /                                                                 " >> /mnt/ramdisk/linuxrc.tst
echo "#############################################################        " >> /mnt/ramdisk/linuxrc.tst
echo "/etc/rc.d/rc.sysinit.IBM_NS.boot                                     " >> /mnt/ramdisk/linuxrc.tst
echo "# revisit this, for now i'm looping...                               " >> /mnt/ramdisk/linuxrc.tst
# yes that while loop is silly, but it didnt seem to like '1' or 'true'.. this works for now. 
echo "while ( ps > /dev/null ) do                                          " >> /mnt/ramdisk/linuxrc.tst
echo "/etc/xkiosk                                                          " >> /mnt/ramdisk/linuxrc.tst
echo "done                                                                 " >> /mnt/ramdisk/linuxrc.tst
echo "#                                                                    " >> /mnt/ramdisk/linuxrc.tst
echo "exit 0                                                               " >> /mnt/ramdisk/linuxrc.tst
echo "                                                                     " >> /mnt/ramdisk/linuxrc.tst
echo "done echo-generating linuxrc " >> /tmp/ramdisk_log

}


function post_createRamDisk
{
       echo "starting post-ramdisk cleanup" >> /tmp/ramdisk_log
       # i don't like this... we might be tight on space and we are
       # losing close to 2Mb of space by copying this and then deleting it
       rm -f /mnt/ramdisk/kernel.*

	# copy the linuxrc file in place.  This may need to be revisited.
	# optionally place the contents within this file and use echo 
	# to /mnt/ramdisk/linuxrc to create it. 
	cp /IBM/FlashRecovery/ramdisk.linuxrc /mnt/ramdisk/linuxrc
	chmod a+x /mnt/ramdisk/linuxrc
	# redundant test step until I can verify that it works OK. 
       write_linuxrc
       chmod a+x /mnt/ramdisk/linuxrc.tst

       # done by mkdevices earlier...
       # mknod /mnt/ramdisk/dev/console c 5 1 

       mkdir /mnt/ramdisk/proc
       #compression
       chattr -c /mnt/ramdisk/proc 


       echo "complete..."
       echo "checking for empty files that may indicate problem with free space"  > /tmp/ramdisk.filelog
       echo "If lots of them show up here, we probally ran out of room in the  " >> /tmp/ramdisk.filelog
       echo "48 MB RAMDisk, meaning that the IDF file is too large.            " >> /tmp/ramdisk.filelog
       echo "note: sometimes files are OK with zero length.                    " >> /tmp/ramdisk.filelog
       find /mnt/ramdisk -type f -size 0 -exec ls -al {} \;                      >> /tmp/ramdisk.filelog

        export dfdata=`/IBM/bin/IBMdf /dev/ram4 | grep ram4 `
	echo $dfdata >> /tmp/ramdisk_log
        export dfspaceleft=`echo $dfdata | cut -d" " -f 4`
	echo $dfspaceleft >>/tmp/ramdisk_log
	echo "space left on ramdisk after image creation " $dfspaceleft >> /tmp/ramdisk_log
        if [ $dfspaceleft -lt 16384 ]; then
        echo "running past 32MB on ramdisk.  up to gz compression to bring it back down to size. " >> /tmp/ramdisk_log
        fi


       echo "unmounting ramdisk"
       umount /mnt/ramdisk
       echo "moving ramdisk image from /dev/ram4 to /root/$RAMDISK_FILENAME "
       dd if=/dev/ram4 bs=1k count=49152 | gzip -v9 > /root/$RAMDISK_FILENAME

       echo "done with image move."

       echo "done with image move. " >> /tmp/ramdisk_log

	echo "ramdisk final size is " `ls -s /root/$RAMDISK_FILENAME` >> /tmp/ramdisk_log

        export lsdata=`ls -s /root/$RAMDISK_FILENAME | cut -f 1 -d" " `

        echo "done with post-ramdisk cleanup" >> /tmp/ramdisk_log
 }


function do_createRamDisk
{

	if [ "$USINGEXISTINGFS" != "y" ] ; then
		file=`echo $1 | cut -c12- `
		M_OPTION="-m $DEFAULT_MOUNTPOINT"
	else
		file=$1
		M_OPTION=
	fi

       F_OPTION="-f"
       T_OPTION="-t 203"

	echo "Now calling lcma, this may take several minutes."
       /IBM/bin/lcmaStart $T_OPTION $F_OPTION -s $file $M_OPTION -r /mnt/ramdisk -c $file

	echo "Now returned from lcma"

        # create a identifier in the ramdisk image.  i.e. a flat file in the
        # ramdisk root that indicates the IDF used to generate it, and the
        # date when it was generated.

        date > /mnt/ramdisk/ramdisk.id
        echo "File:  " $file  >> /mnt/ramdisk/ramdisk.id

       echo "done with create ramdisk function" >> /tmp/ramdisk_log
}


function unmountBootServer
{
	echo -n "Unmounting Server..."
	umount $DEFAULT_MOUNTPOINT
	echo -e " Done."
}


function mountBootServer
{
	if [ $MOUNTPOINT ] && [ $BOOTSERVER ]
		then 
			echo -e "\n\n"
			mkdir -p $DEFAULT_MOUNTPOINT
			# Unmount any left over mounts, before mounting default_mountpoint
			echo "Cleaning up old mount points"
			unmountBootServer
			echo  "Mounting $BOOTSERVER:$MOUNTPOINT  Please wait..."

			if mount $BOOTSERVER:$MOUNTPOINT $DEFAULT_MOUNTPOINT
				then echo -e " Mount successful."
				else
					echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT:"
					unmountBootServer
			fi

		else
			echo -e "\n\n"
			echo -e "Recovery server and mount point not both specified.\n"
			echo -e "Assuming $IMAGENAME is in file system.\n"
			USINGEXISTINGFS=y

	fi
	if [ -f $IMAGENAME ]
		then
			echo -e "Image $IMAGENAME found.\n"
		else
			echo -e "Image not present or not accessible.\n"
			echo "$IMAGENAME was not found on server $BOOTSERVER \n" >> /tmp/ramdisk.error
			exit 1
	fi
	echo -e "\n"
}


#------------------------
# Start Main section 
#------------------------

# define the 'default' mountpoint. 
DEFAULT_MOUNTPOINT=/mnt/update

# wipe out the status file. 
if [ -f /tmp/ramdisk_log ]
then
    rm /tmp/ramdisk_log
fi

if [ -f /tmp/ramdisk_successful ]
then
    rm /tmp/ramdisk_successful
fi

date >> /tmp/ramdisk_log

# wipe out the error file. 
if [ -f /tmp/ramdisk.error ]
then
    rm /tmp/ramdisk.error
fi

# source the file for BOOTSERVER, MOUNTPOINT, IMAGENAME, RAMDISK_FILENAME

if [ -f /IBM/ramdiskcreation ]
then
           .  /IBM/ramdiskcreation
else
	   echo "/IBM/ramdiskcreation source file does not exist.  "
	   echo "/IBM/ramdiskcreation source file does not exist.  " >> /tmp/ramdisk.error
	   exit 1
fi

   # mount the boot server as specified within the ramdiskcreation file.
   mountBootServer

   pre_createRamDisk 
   do_createRamDisk   $IMAGENAME
   post_createRamDisk

  echo "RAMDisk build complete. " >> /tmp/ramdisk_log
  date >> /tmp/ramdisk_log

       if [ $lsdata -gt 32767 ]; then
        echo "ramdisk image is too large for ramdisk TFTP transfer! " >> /tmp/ramdisk_log
        cp /tmp/ramdisk_log /tmp/ramdisk_failure
       else
  cp /tmp/ramdisk_log /tmp/ramdisk_successful
        fi

#--------------
# End Main
#--------------

