#########################################################################
# cf_uninstall.sh                                                       #
#                                                                       #
# Removes the files contained in the old idf, but not in the new idf.   #
# Best described by the following set notation:                         #
#                                                                       #
#     ( NEW ^ OLD ) - NEW                                               #
#                                                                       #
#########################################################################
#!/bin/sh

if [ $# -lt 4 ]; then

   echo "" >&2
   echo "Syntax:" `basename $0` "<new_idf> <old_idf> <new_base> <old_base> [-d | --debug]" >&2
   echo "" >&2
   echo "    new_idf    path and name to new idf" >&2
   echo "    old_idf    path and name to old idf" >&2
   echo "    new_base   base directory of new sdfs and files" >&2	# i.e., the mount point. ( /mnt/update ??)
   echo "    old_base   base directory of old sdfs and files" >&2	# i.e., the mount point. ( /mnt/hd1 ??)
   echo
   echo "    -d" >&2
   echo "    --debug    Do not remove the files, just list them (optional)" >&2
   echo "" >&2

   # Exit with an error return code.
   exit 1

else

   if [ "$5" = "--debug" -o "$5" = "-d" ]; then 
      echo >&2
      echo "debug enabled" >&2
      echo >&2
      XARG_COMMAND="-n1 echo"
   else
      XARG_COMMAND="rm -f"
   fi

   #
   # Programming note: The nested braces below are used as a way of combining 
   # the stdout from multiple commands/pipes to pass as stdin to more commands/pipes.
   #

   {
      {
         # Print to stdout all the files referenced by all the sdfs in the new idf and prepend the filepath with
         # a "NEW " tag to differentiate between files referenced by the old and new idfs.

         for new_sdf in `awk '{if ($1 !~ /[Hh][Ee][Aa][Dd]/) { for (i = 1; i <= NF; i++) {if ($i ~ /[Ss][Rr][Cc]=/) {print substr($i, 5)}}}}' $1`
         do
            awk '{if ($1 !~ /[Hh][Ee][Aa][Dd]/) { for (i = 1; i <= NF; i++) {if ($i ~ /[Dd][Ee][Ss][Tt]=/) {print "NEW " substr($i, 6) }}}}' ${3}${new_sdf}
         done

      # Sort the output, identical lines appear only once.
      } | sort -u
      {
         # Print to stdout all the files referenced by all the sdfs in the old idf and prepend the filepath with
         # a "OLD " tag to differentiate between files referenced by the old and new idfs.

         for old_sdf in `awk '{if ($1 !~ /[Hh][Ee][Aa][Dd]/) { for (i = 1; i <= NF; i++) {if ($i ~ /[Ss][Rr][Cc]=/) {print substr($i, 5)}}}}' $2`
         do
            awk '{if ($1 !~ /[Hh][Ee][Aa][Dd]/) { for (i = 1; i <= NF; i++) {if ($i ~ /[Dd][Ee][Ss][Tt]=/) {print "OLD " substr($i, 6) }}}}' ${4}${old_sdf}
         done

      # Sort the output, identical lines appear only once.
      } | sort -u

   # Sort the output (ignoring the first field), discard duplicate lines (ignoring the first field), delete lines
   # starting with "NEW", throw away the first field of each line, and pipe to xargs command. The xargs
   # command will either display the files (debug mode) or remove the files (regular mode).

   } | sort +1 | uniq -u -1 | sed -n '/^OLD/p' | cut -d' ' -f2 | xargs $XARG_COMMAND

fi

# Exit with a successful return code.
exit 0



