#!/bin/sh

cylinders=`/sbin/sfdisk -l /dev/hda 2>/dev/null | grep Disk | cut -d' ' -f3`
if [ -n "$cylinders" ]; then
   echo "cylinders=$cylinders"

   cylinder_size_bytes=`/sbin/sfdisk -l /dev/hda | grep Units | cut -d' ' -f5`
   echo "cylinder_size_bytes=${cylinder_size_bytes:=65536}"

   blocks_in_all_partitions=`expr $cylinders \* \( $cylinder_size_bytes \/ 1024 \) - 16`
   echo "blocks_in_all_partitions=$blocks_in_all_partitions"

   blocks_in_first_partition=`expr $blocks_in_all_partitions - 1024`
   echo "blocks_in_first_partition=$blocks_in_first_partition"

   num_ext2fs_groups=`expr $blocks_in_first_partition \/ 8192`
   if [ `expr $blocks_in_first_partition % 8192` -ne "0" ]; then
      num_ext2fs_groups=`expr $num_ext2fs_groups + 1`
   fi
   echo "num_ext2fs_groups=$num_ext2fs_groups"

   inode_blocks=`expr $blocks_in_first_partition \/ 33`
   echo "inode_blocks=$inode_blocks"

   inode_blocks_per_group=`expr $inode_blocks \/ $num_ext2fs_groups`
   if [ `expr $inode_blocks % $num_ext2fs_groups` -ne "0" ]; then
      inode_blocks_per_group=`expr $inode_blocks_per_group + 1`
   fi
   echo "inode_blocks_per_group=$inode_blocks_per_group"

   groups_without_super_block=`expr \( $num_ext2fs_groups - 1 \) \/ 2`
   echo "groups_without_super_block=$groups_without_super_block"

   total_unavailable_blocks=`expr 1 + \( 4 + $inode_blocks_per_group \) \* $num_ext2fs_groups - 2 \* $groups_without_super_block`
   echo "total_unavailable_blocks=$total_unavailable_blocks"

   total_useable_blocks=`expr $blocks_in_first_partition - $total_unavailable_blocks`
   echo "total_useable_blocks=$total_useable_blocks"

   total_useable_bytes=`expr $total_useable_blocks \* 1024`
   echo "total_useable_bytes=$total_useable_bytes"
fi











