#!/bin/sh
# ---------------------------------------------------------------------
#
# file_on_persistent_storage.sh
#
# writes the string "yes" to stdout if the input file is located on 
# persistent storage. Persistent storage is defined as NOT a ram disk
# and NOT a read-only mount point. If no file is given for the command,
# or the file fails the persistence-test, then the string "no" is
# written to stdout.
# --------------------------------------------------------------------- 


closest_mount () 
{
   if [ $# -gt 0 ]; then

      mountlist=`cat /proc/mounts | cut -d" " -f2`

      pathlist=$1
      last=$1
      while [ "$last" != "/" ]; do
         last=`dirname $last`
         pathlist="$pathlist $last"
      done

      for path in $pathlist
      do
         for mount in $mountlist
         do
            if [ "$path" = "$mount" ]; then
               echo $mount
               return 0
            fi
         done
      done
   fi
}


cat /proc/mounts | {

   persistent=False
   mountpoint=`closest_mount $*`

   while read dev mount type options rest; do
      if [ "$mount" = "$mountpoint" ]; then

         if [ `echo $dev | cut -c1-8` != "/dev/ram" -a `echo $options | cut -d, -f1` != "ro" ]; then 

            if [ "$dev" = "/dev/root" ]; then
               if [ "$BOOTSOURCE" != "ramdisk" ]; then 
                  persistent=True
                  break;
               fi
            else
               persistent=True
               break
            fi
         fi

         break
      fi
   done

   echo $persistent
}

