#!/bin/sh

############################################################### 
# FILE: match.sh
#
# Reads a patterm file from stdin and returns the second record
# of the first line whose first record matches one of the command
# line arguments of this script.
#
# Example pattern input file:
#
# 1.2.33.80                     __match_specific_ip
# 1.2.33.*                      __match_ring_33
# [0-9a-zA-Z]+.acme.com         __match_acme_domain
# *                             __match_default
#
###############################################################


while :
do

   # Read information from stdin.
   read pattern value

   # If read failed, then exit.
   if [ $? -ne 0 ]; then exit 1; fi

   # Tolerate blank lines.
   if [ "${pattern}" = "" ]; then continue; fi

   # Ignore '#' comments.
   if [ "`echo ${pattern} | awk /^#/`" != "" ]; then continue; fi

   # The '*' character defines the default. i.e., everything matches.
   if [ "${pattern}" = "*" ]; then
      echo ${value}
      exit 0
   fi   

   expr="/${pattern}/"

   for argument in $*
   do
      answer=`echo ${argument} | awk ${expr}`

      if [ "${answer}" != "" ]; then
         echo ${value}
         exit 0
      fi
   done
done



