#!/bin/bash

#
# ReflashBootProm_TCM.sh 
# Script to allow tcm through snmp to invoke a reflash of the boot prom.
# Reads in the server, mount point and file to reflash and invokes the 
# reflash device driver to update the boot prom.
#

#
# Functions #
#

function checkargs # parse out the arguments for server, mount and file
{

	if [ $# -lt 3 ]
		then
			echo -e "\nInvalid number of arguments.\n"
			echo -e "\nInvalid number of arguments.\n" >> $LOG_FILE
                        echo -e "Expecting reflash_tcm.sh <bootserver> <mount_point> <file>"
                        echo -e "Example:  reflash_tcm.sh servername /nstation/linux/proms flashtry.2800\n"
                        /IBM/bin/gentrap 6 4 /IBM/bin/reflash_tcm 204					
                        exit -1
	fi
}

function unmountBootServer
{
	echo -n "Unmounting Server..."
	umount $DEFAULT_MOUNTPOINT
	echo -e " Done."
}

function mount_reflash # mount the server, mount passed in
{
	if [ $MOUNTPOINT ] && [ $BOOTSERVER ]
		then 
			echo -e "\n"
			echo  "Mounting $BOOTSERVER:$MOUNTPOINT  Please wait..."
			mkdir -p $DEFAULT_MOUNTPOINT
			# Unmount any left over mounts, before mounting default_mountpoint
			unmountBootServer

			if mount $BOOTSERVER:$MOUNTPOINT $DEFAULT_MOUNTPOINT >> $LOG_FILE 2>&1
				then
                                        echo -e " Mount successful."
                                        echo -e " Mount successful." >> $LOG_FILE
				else
					echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT:"
					echo -e " ERROR: Mount unsuccessful. Check $BOOTSERVER:$MOUNTPOINT:" >> $LOG_FILE
					unmountBootServer
                                        /IBM/bin/gentrap 6 4 /IBM/bin/reflash_tcm 204					
                                         exit -1
			fi

		else
			echo -e "\n\n"
			echo -e "Boot server and mount point not both specified.\n"
			echo -e "Boot server and mount point not both specified.\n" >> $LOG_FILE
			echo -e "This need to be specified before continuing.\n"
                        /IBM/bin/gentrap 6 4 /IBM/bin/reflash_tcm 204					
                        exit -1

	fi
	echo -e "\n"
}


function reflash_prom # code to call reflash program that controls reflash dd
{
       # Check that the flash image exists
       if [ ! -e $DEFAULT_MOUNTPOINT/$REFLASHFILE ]
       then
          echo -e "Flash image file does not exist on server: $DEFAULT_MOUNTPOINT/$REFLASHFILE" >> $LOG_FILE
          echo -e "Flash image file does not exist on server: $DEFAULT_MOUNTPOINT/$REFLASHFILE"
          unmountBootServer
          /IBM/bin/gentrap 6 4 /IBM/bin/reflash_tcm 204          
         exit -1
       fi

        # Pop up a warning message using the broadcast message facility in Setup Utility
        echo -e $WARNING > /tmp/IBM/Messages/`date +"%s"`
        # Give it 3 sec for Setup Utility to notice the message before reflashing
        sleep 3 

        if /IBM/bin/tcm_reflash_util $DEFAULT_MOUNTPOINT/$REFLASHFILE >> $LOG_FILE 2>&1
		           then
                           echo -e " Flash completed successfully."
		           echo -e " Flash completed successfully." >> $LOG_FILE

							 # Send good completion trap	
               /IBM/bin/gentrap 6 3 /IBM/bin/reflash_tcm 204
                           # Reboot the system
                           /IBM/bin/reboot_IBM_NS 5	
                exit 0
		    else
		            echo -e " Flash not updated due to errors."
		            echo -e " Flash not updated due to errors." >> $LOG_FILE
							 # Send error completion trap								
               /IBM/bin/gentrap 6 4 /IBM/bin/reflash_tcm 204								
                exit -1
        fi
}       

#
# Beginning of time #
#

# Pass in server, mount and file.  
# 	Ex:  reflash_tcm.sh brak /nstation/linux/proms flash.2800
BOOTSERVER=$1
MOUNTPOINT=$2
REFLASHFILE=$3

# Message pop-up to warn the user
WARNING="ATTENTION:\n\nDO NOT POWER OFF THE WORKSTATION!\nA firmware update is occurring on this workstation.\nThe mouse and keyboard will be locked during the update.\nThe workstation will be rebooted when the update is completed."

# Special set up based on the boot source.
if [ "$BOOTSOURCE" = "peer" -o "$BOOTSOURCE" = "ramdisk" ]           
then
  # Peer or ramdisk booted.  Don't have a writable file system.
  # Log to the bit bucket
  LOG_FILE=/dev/null
  # Mount the server to /tmp
  DEFAULT_MOUNTPOINT=/tmp/firmwareupdate
else
  # Server or flash boot.  Have a writable file system.
  if [ ! -e /var/log/lcma ]; then
    mkdir -p /var/log/lcma
  fi
  LOG_FILE=/var/log/lcma/client_task.log
  DEFAULT_MOUNTPOINT=/mnt/reflash
  echo "Error information will be logged to /var/log/lcma/client_task.log"
fi

echo -e "Update starting" > $LOG_FILE

checkargs $BOOTSERVER $MOUNTPOINT $REFLASHFILE
mount_reflash
reflash_prom

#echo "server $BOOTSERVER"
#echo "mount point $MOUNTPOINT"
#echo "file $REFLASHFILE"
