#--------------------------------------------------------------------------------
#!/bin/sh
#
# /etc/rc.d/rc.sysinit.IBM_NS.bcot - run once at boot time
# Modified for IBM NetVista clients running Linux
#
# This file is subject to the terms and conditions of the GNU General Public
# License.  See the file "COPYING" in the base directory of this archive
# for more details.
#
# Calls other scripts like:
#   rc.IBM_NS.machine_dir
#   rc.IBM_NS.dev
#   rc.IBM_NS.tmp
#   rc.IBM_NS.var
#   rc.IBM_NS.net
#   rc.IBM_NS.hardware
#
# --------------------------------------------------------------------------------

# ------------------------------------------------------------------------
# #############  Setup Environment ###############
# ------------------------------------------------------------------------
export LINUX_NC_VENDOR=`awk {'print $1'} /IBM/linuxDistribution`

if [ "$LINUX_NC_VENDOR" = "TurboLinux" ]; then
   export LINUX_NC_DIST=`awk {'print $3'} /IBM/linuxDistribution`
else
   export LINUX_NC_DIST=`awk {'print $2'} /IBM/linuxDistribution`
fi

export LINUX_BUILD_DATE=`awk {'print $NF'} /IBM/linuxDistribution`

# Specify the directory of NetVista specific configuration files - usually tmp. 
# The value here must match the value in the create_bootdir_from_rpm installation
# script.
export TMP_DIR=tmp

# Set the path
export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/IBM/bin:/usr/X11R6/bin

# Default RAM disk numbers
export DEV_RAM=ram1
export TMP_RAM=ram2
export TEMPAPPS_RAM=ram3


# ------------------------------------------------------------------------
# #############  Parse /proc/cmdline parameters and export them ###############
#   command line parms contains root-bootype ip, subnet, gw, h/w type etc.
# ------------------------------------------------------------------------
mount -n -t proc /proc /proc
echo "Parse command line parameters"
if [ -f /proc/cmdline ]; then
  pf=1                      # Assume platform (pf) to be 2800 - replaced by cmdline_parms
  `awk -f/bin/cmdline_export_awk /proc/cmdline`
   if [ "$root" == "" ]; then
      export root=$AAAAroot
   fi
   echo cmdline exports:: root:$root ip:$ip gw:$gateway subnet:$subnetmask
   echo                   server:$server baseDir=$serverBaseDir pf:$pf n1:$n1 n2:$n2
   echo " "
fi
# ------------------------------------------------------------------------

# check what model is running
if [ $pf = "1" ]; then
   MODEL_TYPE=2800
elif [ $pf = "2" ]; then
   MODEL_TYPE=2200
else
   MODEL_TYPE=unknown
fi
export MODEL_TYPE

if touch /.peertest > /dev/null 2>&1 ; then
   rm -f /.peertest
else
   mountType="ro"
fi

# check whether we are server booted, flash booted or running from a ramdisk
if [ $root = "/dev/hda1" ]; then
   BOOTSOURCE=flash
elif [ -f /ramdisk.id ]; then
   /bin/echo "This is a RAMDISK boot "
   BOOTSOURCE=ramdisk
elif [ $root = "nfs" -a "$mountType" = "ro" ]; then
   BOOTSOURCE=peer
else
   # this could be a ram disk too so we need to add this check yet
   BOOTSOURCE=server
fi
export BOOTSOURCE

. /etc/rc.d/profile.IBM_NS.init

/etc/rc.d/rc.IBM_NS.dev

if [ $BOOTSOURCE = "flash" ]; then
   mount -n -o remount,ro / /
   # fsck the flash card
   /sbin/e2fsck -C -T -a /dev/hda1
   /sbin/e2fsck -C -T -a /dev/hda2
fi

# set up the loopback device and start portmapper
ifconfig lo 127.0.0.1
route add -net 127.0.0.0 netmask 255.0.0.0 dev lo
/sbin/portmap

# remount / read/write or read only if peer booted.
if [ $BOOTSOURCE = "peer" ]; then
 mount -n -o remount,ro / /
 mount -r -t nfs $server:/root /root
else
 mount -n -o remount,rw / /
fi


# ------------------------------------------------------------------------
# #### Set-up machine specific dir, if MACHINE_BASE_DIR is specified  ####
#
# Check if there is machine specific RW directories - if so, set up system to use it
# Handle machined based specific directories - like tmp, var/spool, etc...
# Curently its based on IP - could be based on MAC address
# All variables be in an external file - /etc/rc.d/machineDir.IBM_NS.setup
# ------------------------------------------------------------------------
echo "52 machine setup" > /proc/progress

if [ -f /etc/rc.d/machineDir.IBM_NS.setup ]; then
  . /etc/rc.d/machineDir.IBM_NS.setup
  export MACHINE_BASE_DIR=$MACHINE_BASE_DIR
  export MACHINE_TEMPLATE=$MACHINE_TEMPLATE
  export MACHINE_DATA_PERSISTENT=$MACHINE_DATA_PERSISTENT
  export MACHINE_DIRECTORY_TYPE=$MACHINE_DIRECTORY_TYPE
  echo "Machine Specific dir: $MACHINE_BASE_DIR, Template: $MACHINE_TEMPLATE"  
fi

# ------------------------------------------------------------------------
# ##### Process /tmp (RAM disk or MACHINE_BASE_DIR)    ######
# ------------------------------------------------------------------------
echo "56 tmp setup" > /proc/progress

# Clear mtab
rm -f /tmp/mtab

# peer boot - /sbin/depmod tries to write back to host
/sbin/depmod -a

/etc/rc.d/rc.IBM_NS.tmp

echo "59" > /proc/progress

if [ $BOOTSOURCE != "flash" ]; then
   /etc/rc.d/rc.IBM_NS.loadDDs
fi

echo "62" > /proc/progress

# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
# ############## Set-up var directory  ##############
# ------------------------------------------------------------------------
echo "64 var setup" > /proc/progress
if [ $BOOTSOURCE = "ramdisk" ]; then
  mkdir -p /var/lock/subsys
  mkdir -p /var/snmp
  mkdir -p /var/log
  mkdir -p /var/run
  mkdir -p /var/tmp
  mkdir -p /tmp/home
  mkdir -p /tmp/snmp
fi


if [ $BOOTSOURCE = "flash" ]; then
   echo -e "Setting up flash partition 2\r"
   mount -n /dev/hda2 /root
   mount -f /
   mount -f /proc
   mount -f /root
fi

echo "68" > /proc/progress

/etc/rc.d/rc.IBM_NS.var
# ------------------------------------------------------------------------

echo "70" > /proc/progress

# Source functions
. /etc/rc.d/init.d/functions

# Print a banner. ;)
echo -e "\n\t\t\tWelcome to Linux\n"


# ------------------------------------------------------------------------
# ############## Configure network settings  ##############
# ------------------------------------------------------------------------
echo "72 net setup" > /proc/progress
/etc/rc.d/rc.IBM_NS.net
# ------------------------------------------------------------------------


# ------------------------------------------------------------------------
# ############# Make h/w specific decisions for 2800, 2200  ##############
# ------------------------------------------------------------------------
echo "75 hardware setup" > /proc/progress
/etc/rc.d/rc.IBM_NS.hardware
# ------------------------------------------------------------------------

# check if we are in EZNS stupified menu mode...
/IBM/bin/readNvram 60
if [ `cat /tmp/snmp/60` = "1" ]; then
   /IBM/bin/writeNvram 60 0
fi

echo "80" > /proc/progress

# ------------------------------------------------------------------------
# ############  Set date, if Timeserver is set  ##############
# ------------------------------------------------------------------------
if [ $BOOTSOURCE = "flash" -o $BOOTSOURCE = "peer" ]; then
   TIMECONFIGFILE=/root/KIOSK/IBM/IBMSetupTimeServerInfo
else
   TIMECONFIGFILE=/root/IBM/IBMSetupTimeServerInfo
fi
if [ -f $TIMECONFIGFILE ]; then
   . $TIMECONFIGFILE
   if [ ! "$timeprotocol" ]; then
      timeprotocol=ntp
   fi

   ln -sf /usr/share/zoneinfo/${timezone} /tmp/localtime
   ln -sf /tmp/localtime /etc/localtime

   if [ "$timeserver" != "" ]; then
      if [ "$timeprotocol" = "ntp" ]; then
         ntpdate $timeserver
      elif [ "$timeprotocol" = "rdate" ]; then
         rdate -s $timeserver
	 
      fi
   fi
fi
# ------------------------------------------------------------------------

# ------------------------------------------------------------------------
# ############  Set up X11  #########
# ------------------------------------------------------------------------
echo "82 x11 setup" > /proc/progress
/etc/rc.d/rc.IBM_NS.x11

echo "83" > /proc/progress
/etc/rc.d/rc.IBM_NS.login

echo "84" > /proc/progress
/etc/rc.d/rc.IBM_NS.mount

echo "85" > /proc/progress
/etc/rc.d/rc.IBM_NS.apps


if [ -f /tmp/hostname ]; then
   . /tmp/hostname
else
   HOSTNAME=localhost
fi

hostname ${HOSTNAME}
echo ${HOSTNAME} > /$TMP_DIR/HOSTNAME

# Remount the root filesystem read-write.
# echo "Remounting root filesystem in read-write mode."
# mount -n -o remount,rw /

echo "Mount complete"

# Clean out /etc.
rm -f /etc/mtab~ /fastboot /fsckoptions

# ------------------------------------------------------------------------
#   Having /var/run/utmp is creating problem during login (mingetty) when utmp is 
#   in MACHINE_DIR and not in BOOT_DIR. The only way it works is to have 
#   MACHINE_DIR /var/run/utmp linked to BOOT_DIR. However, this causes problem 
#   where we would like BOOT_DIR to be READ-ONLY (our goal). 
#   The solution is not to have run/utmp (so far it has not caused problems. 
#   Will need more testing). 
# The commented code is the original code
# ------------------------------------------------------------------------
>/var/run/utmp
# ------------------------------------------------------------------------

# Delete UUCP lock files.

# Delete stale subsystem files.
rm -f /var/lock/subsys/*

if [ -n "$KERNELD" ]; then
    touch /var/lock/subsys/kerneld
fi

# Delete stale pid files
rm -f /var/run/*.pid

# Delete X locks
rm -f /$TMP_DIR/.X*-lock

# Delete Postgres sockets
rm -f /$TMP_DIR/.s.PGSQL.*

# Initialize the serial ports.
if [ -f /etc/rc.d/rc.serial -a $MODEL_TYPE = "2800" ]; then
	. /etc/rc.d/rc.serial
fi

# Load modules (for backward compatibility with VARs)
if [ -f /etc/rc.d/rc.modules ]; then
     /etc/rc.d/rc.modules
fi

# Use any system tuning features that user might have installed
if [ -f /etc/rc.d/rc.turbo ]; then
  /etc/rc.d/rc.turbo
fi

# Now that we have all of our basic modules loaded and the kernel going,
# let's dump the syslog ring somewhere so we can find it later
if [ -f /bin/dmesg ]; then
   dmesg > /var/log/dmesg
fi

echo "86" > /proc/progress
if [ -f /etc/rc.d/init.d/network ]; then
   /etc/rc.d/init.d/network start
fi  

echo "88" > /proc/progress
if [ -f /etc/rc.d/init.d/portmap ]; then
   /etc/rc.d/init.d/portmap start
fi

echo "90" > /proc/progress
if [ -f /etc/rc.d/init.d/syslog ]; then
   /etc/rc.d/init.d/syslog start
fi

echo "92" > /proc/progress
if [ -f /etc/rc.d/init.d/snmpd ]; then
   /etc/rc.d/init.d/snmpd start
fi 

echo "94" > /proc/progress
if [ $BOOTSOURCE = "flash" ]; then

  if [ -f /root/KIOSK/IBM/IBMSetupInformationBlock ]; then
     . /root/KIOSK/IBM/IBMSetupInformationBlock 
  fi

  if [ ! "$PEERBOOT_ENABLE" = "n" -a -f /etc/rc.d/init.d/nfs ]; then
     modprobe nfsd
     echo "Starting nfs..."
     {
        sleep 10 
        /etc/rc.d/init.d/nfs start
     } &
  fi 
fi

echo "96" > /proc/progress
if [ -f /etc/rc.d/init.d/keytable ]; then
   /etc/rc.d/init.d/keytable start
fi 
 
echo "98" > /proc/progress
if [ -f /etc/rc.d/init.d/lpd ]; then
   /etc/rc.d/init.d/lpd start
fi 

if [ -f /IBM/bin/idfd ]; then
   /IBM/bin/idfd &
fi
 
if [ -f /etc/rc.d/rc.local ]; then
   /etc/rc.d/rc.local
fi

cat /proc/mounts > /etc/mtab

echo "BOOTSOURCE=$BOOTSOURCE" > /tmp/environment

echo "100" > /proc/progress

/sbin/ldconfig

if [ $BOOTSOURCE = "flash" -o $BOOTSOURCE = "ramdisk" -o $BOOTSOURCE = "peer" ]; then

   # ------------- Creating startx file ---------------
   echo -e "Creating startx file\r"
   echo "export PATH=/bin:/usr/X11R6/bin:/sbin:/usr/local/bin:/usr/bin:/IBM/bin:." > /tmp/startx
   echo "export SHELL=/bin/sh" >> /tmp/startx
   echo "export TERM=xterm" >> /tmp/startx
   echo "export XINITRC=/usr/X11R6/lib/X11/xinit/xinitrc" >> /tmp/startx
   echo "export USER=KIOSK" >> /tmp/startx
   echo "export USERNAME=KIOSK" >> /tmp/startx
   echo "export HOME=/home/KIOSK" >> /tmp/startx

   echo "/usr/X11R6/bin/xinit" >> /tmp/startx
   echo "sync" >> /tmp/startx
   echo "sync" >> /tmp/startx

fi


