#!/bin/sh
################################################################################
# Name: rh_install.sh
#
# Purpose: Create a RedHat 6.1 tree for serving IBM NetVista
#          thin clients
# Last edited: 8/23/00
# Command:
#  rh_install.sh
################################################################################

################################################################################
# reboot_Warning
################################################################################
function reboot_Warning
{
	echo "If installing on a server other than RedHat Linux server, upon completion of"
	echo "this install, the system must be rebooted (see install html for more info):"
        echo ""
	echo -n "Do you wish to continue? (Yes/No) "; read
	case $REPLY in
		[yY]|[yY][eE][sS])
			;;
		[nN]|[nN][oO])
			echo ""
			exit 0;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			reboot_Warning;;
	esac
}

################################################################################
# what_client_to_install
################################################################################
function what_client_to_install
{
	echo "Please select the client you wish to install:"
	echo "  1. RedHat 6.1 "
	echo "  2. RedHat 6.2 "
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])
                    . CONFIG/rh61.config;;
		[2])
                    . CONFIG/rh62.config;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			what_client_to_install;;
	esac
}


################################################################################
# Main Body
################################################################################

set +x

# =======  Set Linux distribution specific Variables - used by calling script files ========

# --- Default settings - the ACTUAL settings come from the selection by the user

#default client info
export CLIENT_VENDOR=RedHat
export CLIENT_DISTRIBUTION=6.1

#  default RPM list file for the Linux distrubution
export RPM_LIST_FILE=RPM_LISTS/rh61_rpm.list

# default CFBuilder
export CFBUILDER="Common/CFBuilder/CFBuilder_2.5_RedHat61_*"


# ============ Start ======================
# Let's clear the screen to make things cleaner looking
clear
echo -e "\nWelcome to the IBM NetVista Thin Client RedHat Linux Installer\n"

export CURDIR=`pwd`

TEMP_SCRIPT_LOC=`ps axo command | grep -v grep | grep rh_install | cut -f2 -d" " | tr -s "\n" "\t" | cut -f1`
SCRIPT_LOC=${TEMP_SCRIPT_LOC%/*}
cd $SCRIPT_LOC

#echo TEMP_SCRIPT_LOC = $TEMP_SCRIPT_LOC
#echo SCRIPT_LOC = $SCRIPT_LOC

# ========== Ask if rebooting is ok =================
# reboot_Warning

# ========== Tell the administrator where the installation log can be found ===========
echo -e "\nAfter the installation has finished, the install log files will be located in $SCRIPT_LOC/tmp."
echo -e "If there are problems, please look at the following files."
echo -e "\tinstall.log	- messages from the IBM install"
echo -e "\trpm.log 	- messages generated during install of the rpm's"
echo -e "\trpm.err		- errors from the rpm install (most of these can be ignored)"

# ========== Ask what client to install =================
# Once the RedHat 6.2  rpm list is finalised, use the function, until then use rh61.config file
#what_client_to_install
. CONFIG/rh7x.config

# From the Function what_client_to_install
echo " "
export CLIENT_DISTRIBUTION
export RPM_LIST_FILE
export CLIENT_VENDOR
export NUMCDS


# ==========  Execute common script file for all client distributions  ====================
Common/scripts/common_install.sh 2>&1 | tee tmp/install.log

if [ $? != "0" ]; then
   echo "Installation aborting"
   exit 1
fi

# ==========  Be sure the administrator did not exit early ===================
# Need to do a two fold check because of points at which the administrator
# can abort the installation
if [ -f tmp/bootDirValue ]; then
        . tmp/bootDirValue
        if [ ! -e $BOOT_DIR/IBM/linuxDistribution ]; then
                echo -e "\nInstallation aborted\n"
                exit 0
        fi
else
        echo -e "\nInstallation aborted\n"
        exit 0
fi


#
# Now that the entire image is installed, and the files have been stripped, update
# the installed IDFs in order to report the correct SIZE, CRC, COMPRESSED_SIZE, etc.
#
${BOOT_DIR}/opt/IBMJava2-13/jre/bin/java -cp ${BOOT_DIR}/IBM/update/LCMT.jar UpdateIDF -d ${BOOT_DIR} /IBM/update/idf /IBM/update/sdf




# ==========   DONE - Time to reboot if using a server other than RedHat   ====================
#  Reboot is done to solve the /proc problem 
# -------------------------------------------------------

rm -Rf $BOOT_DIR/etc/X11/gdm
ln -sf /etc/gdm $BOOT_DIR/etc/X11

echo -e "\nInstallation is Complete\n"
. tmp/bootDirValue
#echo "SERVER=$SERVER" 
REDHAT="RedHat Linux"

if [ -f /etc/rc.d/init.d/nfsserver ]; then
   /etc/rc.d/init.d/nfsserver start
else
   /etc/rc.d/init.d/nfs start
fi


echo ""
echo "INSTALLATION IS COMPLETE !!! "
echo ""
