#!/bin/sh
################################################################################
# Name: tl_install.sh
# Purpose: Create a TurboLinux tr
# Command:
#  tl_install.sh
################################################################################

################################################################################
# reboot_Warning
################################################################################
function reboot_Warning
{
	echo "Upon completion of this install, the system must be rebooted."
	echo -n "Do you wish to continue? (Yes/No) "; read
	case $REPLY in
		[yY]|[yY][eE][sS])
			;;
		[nN]|[nN][oO])
			echo ""
			exit 0;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			reboot_Warning;;
	esac
}

################################################################################
# what_client_to_install
################################################################################
function what_client_to_install
{
	echo "Please select the client you wish to install:"
	echo "  1. TurboLinux WorkStation 6.0.7 (Official IBM distribution) "
	echo "	2. TurboLinux WorkStation 6.0.5 "
	echo "  3. TurboLinux WorkStation 6.0 "
        echo -n "Enter Selection: "; read
	case $REPLY in
		[1])
                    . CONFIG/tlw607.config;;
		[2])
                    . CONFIG/tlw605.config;;
		[3])
                    . CONFIG/tlw60.config;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			what_client_to_install;;
	esac
}

function continueQuestion
{
	echo -ne "\nDo you wish to continue? (Yes/No) "
	read input
	case $input in
		[yY]|[yY][eE][sS]) ;;
		[nN]|[nN][oO]) exit;;
		*)
			echo -e "\n\nInvalid Response\n\n"
			continueQuestion;;
	esac
}
               
################################################################################
# Main Body
################################################################################
function main_body
{
README="/tmp/README.html"
umask 022
set +x
export PATH=/sbin:/usr/sbin:$PATH
# =======  Set Linux distribution specific Variables - used by calling script files ========


# default client info
export CLIENT_VENDOR=TurboLinux

# default RPM list file for the Linux distrubution
export RPM_LIST_FILE=RPM_LISTS/tlw60x_rpm.list



# ============ Start ======================
# Let's clear the screen to make things cleaner looking
clear
echo -e "\nWelcome to the IBM NetVista Thin Client TurboLinux Installer\n"

export CURDIR=`pwd`

TEMP_SCRIPT_LOC=`ps axo command | grep -v grep | grep -v ez | grep -v vi |grep tl_install | cut -f2 -d" " | tr -s "\n" "\t" | cut -f1`
SCRIPT_LOC=${TEMP_SCRIPT_LOC%/*}
cd $SCRIPT_LOC

#echo TEMP_SCRIPT_LOC = $TEMP_SCRIPT_LOC
#echo SCRIPT_LOC = $SCRIPT_LOC

# ========== Ask if rebooting is ok =================
# reboot_Warning


# ========== Tell the administrator where the installation log can be found ===========
echo -e "\nAfter the installation has finished, the installation log (install.log) will be"
echo "located in $SCRIPT_LOC/tmp directory"
echo -e " - Please review this file if problems are encountered.\n" 

# ========== Ask what client to install =================
#if [ ! -f /tmp/nvltc_type ]; then
#   # Invoked from toolkit - give user a choice
#   what_client_to_install
#else  
   # Invoked from official build CD - this is a fixed distribution - No choice given
   . CONFIG/tlw60x.config
# fi
# From the Function what_client_to_install
echo " "
export CLIENT_DISTRIBUTION
export RPM_LIST_FILE
export CLIENT_VENDOR

# lets set up the base install steps that a Turbo install would do....
# we just need to know the BOOT_DIR


# ==========  Execute common script file for all client distributions  ====================
Common/scripts/common_install.sh 2>&1 | tee tmp/install.log

# ==========  Be sure the administrator did not exit early ===================
# Need to do a two fold check because of points at which the administrator
# can abort the installation

if [ -f tmp/bootDirValue ]; then
	. tmp/bootDirValue
	if [ ! -e $BOOT_DIR/IBM/linuxDistribution -o -e tmp/error ]; then
		echo -e "\nInstallation aborted\n"
		exit 0
	fi
else
	echo -e "\nInstallation aborted\n"
	exit 0
fi

# ==========  Copy the CD README.html file to the /IBM directory  ====================
if [ -e $README ]; then
	cp $README $BOOT_DIR/IBM/
	rm $README
fi


# modify ICA so it can run on nt...
# rpm contains 2 files Wfcmgr and wfcmgr which causes problems
# with NT's case sensitivy or lack of
if [ -d $BOOT_DIR/usr/lib/ICAClient.orig ]; then
   rm -Rf $BOOT_DIR/usr/lib/ICAClient.orig
fi

if [ -f $BOOT_DIR/usr/lib/ICAClient/wfica ]; then
   mv $BOOT_DIR/usr/lib/ICAClient/wfica $BOOT_DIR/usr/lib/ICAClient/wfica.ibm
fi
if [ -f $BOOT_DIR/usr/lib/ICAClient/wfcmgr ]; then
   mv $BOOT_DIR/usr/lib/ICAClient/wfcmgr $BOOT_DIR/usr/lib/ICAClient/wfcmgr.ibm
fi
if [ -d $BOOT_DIR/usr/lib/ICAClient ]; then
   mv $BOOT_DIR/usr/lib/ICAClient $BOOT_DIR/usr/lib/ICAClient.orig
fi

# Copy the ICA plugin to the netscape directory.
if [ -f $BOOT_DIR/usr/lib/ICAClient.orig/npica.so ]; then
   cp $BOOT_DIR/usr/lib/ICAClient.orig/npica.so $BOOT_DIR/usr/lib/netscape-4.77-1/plugins/npica.so
fi

# ==========  Remove some doc directories since we didn't install docs  ====================
rm -rf $BOOT_DIR/usr/share/doc
rm -rf $BOOT_DIR/usr/X11R6/doc
rm -rf $BOOT_DIR/usr/X11R6/man/ja_JP.ujis
rm -rf $BOOT_DIR/usr/doc
rm -rf $BOOT_DIR/usr/local/doc


#
# Now that the entire image is installed, and the files have been stripped, update
# the installed IDFs in order to report the correct SIZE, CRC, COMPRESSED_SIZE, etc.
#
${BOOT_DIR}/opt/IBMJava2-13/jre/bin/java -cp ${BOOT_DIR}/IBM/update/LCMT.jar UpdateIDF -d ${BOOT_DIR} /IBM/update/idf /IBM/update/sdf


# ==========   DONE - Time to reboot  ====================
echo -e "\nInstallation is Complete - Remove the $CLIENT_VENDOR CD\n"
echo -e "Restarting nfs daemon\n"
echo ""

if [ -f /etc/rc.d/init.d/nfsserver ]; then
   /etc/rc.d/init.d/nfsserver start
elif [ -f /etc/rc.d/nfs ]; then
   /etc/rc.d/nfsserver start
else
   /etc/rc.d/init.d/nfs start
fi
}
main_body
